==> haskell-type-equality-1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-equality.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-equality
version:              1
visibility:           public
id:                   type-equality-1-LChjcnrhNt95Zw0nihMDH4
key:                  type-equality-1-LChjcnrhNt95Zw0nihMDH4
license:              BSD-3-Clause
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, Ryan Scott <ryan.gl.scott@gmail.com>, Erik Hesselink <hesselink@gmail.com>

author:
    Oleg Grenrus <oleg.grenrus@iki.fi>, Ryan Scott <ryan.gl.scott@gmail.com>, Erik Hesselink <hesselink@gmail.com>, Martijn van Steenbergen

stability:            provisional
homepage:             https://github.com/hesselink/type-equality
synopsis:             Data.Type.Equality compat package
description:
    This library defines a propositional equality data type,
    shims @Data.Type.Equality" as well as possible for older GHCs (< 7.8).

    @
    data a :~: b where
    \    Refl :: a :~: a
    @

    The module @Data.Type.Equality.Hetero@ shims @:~~:@ equality, for
    compilers with @PolyKinds@

category:             Data, Dependent Types
abi:                  b49f9bb3741c08eb2fac037554d29e97
exposed:              True
exposed-modules:      Data.Type.Equality.Hetero
import-dirs:          /usr/lib/ghc-9.0.2/site-local/type-equality-1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/type-equality-1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/type-equality-1
hs-libraries:         HStype-equality-1-LChjcnrhNt95Zw0nihMDH4
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-type-equality/html/type-equality.haddock

haddock-html:         /usr/share/doc/haskell-type-equality/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-equality-1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-equality.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-equality
version:              1
visibility:           public
id:                   type-equality-1-7cpy6BQKA5x3RAxcxQYjWu
key:                  type-equality-1-7cpy6BQKA5x3RAxcxQYjWu
license:              BSD-3-Clause
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, Ryan Scott <ryan.gl.scott@gmail.com>, Erik Hesselink <hesselink@gmail.com>

author:
    Oleg Grenrus <oleg.grenrus@iki.fi>, Ryan Scott <ryan.gl.scott@gmail.com>, Erik Hesselink <hesselink@gmail.com>, Martijn van Steenbergen

stability:            provisional
homepage:             https://github.com/hesselink/type-equality
synopsis:             Data.Type.Equality compat package
description:
    This library defines a propositional equality data type,
    shims @Data.Type.Equality" as well as possible for older GHCs (< 7.8).

    @
    data a :~: b where
    \    Refl :: a :~: a
    @

    The module @Data.Type.Equality.Hetero@ shims @:~~:@ equality, for
    compilers with @PolyKinds@

category:             Data, Dependent Types
abi:                  d56de4de6a239435829f9376bb540e6d
exposed:              True
exposed-modules:      Data.Type.Equality.Hetero
import-dirs:          /usr/lib/ghc-9.2.8/site-local/type-equality-1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/type-equality-1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-equality
hs-libraries:         HStype-equality-1-7cpy6BQKA5x3RAxcxQYjWu
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-type-equality/html/type-equality.haddock

haddock-html:         /usr/share/doc/haskell-type-equality/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
